@@ -2,12 +2,14 @@ import os
 import json
 from datetime import datetime, date
 import dataclasses
-from typing import List, Optional, Callable, Sequence, Any
+from typing import List, Optional, Callable, Sequence, Any, Dict, Type, Tuple
 
 import click
 
 
-@click.group()
+@click.group(
+    context_settings={"help_option_names": ["-h", "--help"], "max_content_width": 120}
+)
 @click.option(
     "--verbose/--quiet",
     default=None,
@@ -30,16 +32,48 @@ def main(verbose: Optional[bool]) -> None:
             log.logger = log.setup(level=logging.ERROR)
 
 
+# use the union of types to determine the possible filters
+from .models import DEFAULT_MODEL_TYPE, get_union_args
+
+model_types: Optional[Tuple[Type[DEFAULT_MODEL_TYPE]]] = get_union_args(
+    DEFAULT_MODEL_TYPE
+)
+assert model_types is not None
+
+FILTER_OPTIONS: Dict[str, Type[DEFAULT_MODEL_TYPE]] = {
+    t.__name__: t for t in model_types
+}
+
+from .locales.all import LOCALES
+
 SHARED = [
     click.option("--cache/--no-cache", default=False, show_default=True),
     click.option(
         "-a",
         "--action",
-        type=click.Choice(["repl", "summary", "json"]),
+        type=click.Choice(["repl", "summary", "json"], case_sensitive=False),
         default="repl",
         help="What to do with the parsed result",
         show_default=True,
     ),
+    click.option(
+        "-l",
+        "--locale",
+        type=click.Choice(LOCALES, case_sensitive=False),
+        default=None,
+        help="Locale to use for matching filenames [default: EN]",
+        show_default=True,
+        envvar="GOOGLE_TAKEOUT_PARSER_LOCALE",
+        show_envvar=True,
+    ),
+    click.option(
+        "-f",
+        "--filter",
+        "filter_",
+        type=click.Choice(list(FILTER_OPTIONS.keys()), case_sensitive=False),
+        multiple=True,
+        help="Filter to only show events of this type. Can be provided multiple times",
+    ),
 ]
 
 
@@ -54,7 +88,7 @@ def _serialize_default(obj: Any) -> Any:
     if isinstance(obj, Exception):
         return {"type": type(obj).__name__, "value": str(obj)}
     elif dataclasses.is_dataclass(obj):
-        d = dataclasses.asdict(obj)
+        d = dataclasses.asdict(obj)  # type: ignore[call-overload]  # see https://github.com/python/mypy/issues/17550
         assert "type" not in d
         d["type"] = type(obj).__name__
         return d
@@ -70,7 +104,7 @@ def _handle_action(res: List[Any], action: str) -> None:
         import IPython  # type: ignore[import]
 
         click.echo(f"Interact with the export using {click.style('res', 'green')}")
-        IPython.embed()
+        IPython.embed()  # type: ignore[no-untyped-call]
     elif action == "json":
         click.echo(json.dumps(res, default=_serialize_default))
     else:
@@ -83,36 +117,81 @@ def _handle_action(res: List[Any], action: str) -> None:
 @main.command(short_help="parse a takeout directory")
 @shared_options
 @click.argument("TAKEOUT_DIR", type=click.Path(exists=True), required=True)
-def parse(cache: bool, action: str, takeout_dir: str) -> None:
+def parse(
+    cache: bool,
+    locale: Optional[str],
+    action: str,
+    takeout_dir: str,
+    filter_: Sequence[str],
+) -> None:
     """
     Parse a takeout directory takeout
     """
-    from .common import Res
-    from .models import BaseEvent
     from .path_dispatch import TakeoutParser
+    from .log import logger
 
-    tp = TakeoutParser(takeout_dir, error_policy="drop")
+    tp = TakeoutParser(
+        takeout_dir,
+        error_policy="drop",
+        locale_name=locale,
+    )
+    filter_type = tuple(FILTER_OPTIONS[ff] for ff in filter_)
     # note: actually no exceptions since since they're dropped
-    res: List[Res[BaseEvent]] = list(tp.parse(cache=cache))
+    if cache:
+        if filter_:
+            logger.warn(
+                "As it would otherwise re-compute every time, filtering happens after loading from cache"
+            )
+        res = list(tp.parse(cache=True))
+        if filter_:
+            res = [r for r in res if isinstance(r, filter_type)]
+    else:
+        res = list(tp.parse(cache=False, filter_type=filter_type))
     _handle_action(res, action)
 
 
 @main.command(short_help="merge multiple takeout directories")
 @shared_options
 @click.argument("TAKEOUT_DIR", type=click.Path(exists=True), nargs=-1, required=True)
-def merge(cache: bool, action: str, takeout_dir: Sequence[str]) -> None:
+def merge(
+    cache: bool,
+    locale: Optional[str],
+    action: str,
+    takeout_dir: Sequence[str],
+    filter_: Sequence[str],
+) -> None:
     """
     Parse and merge multiple takeout directories
     """
     from .path_dispatch import TakeoutParser
     from .merge import cached_merge_takeouts, merge_events
-    from .models import DEFAULT_MODEL_TYPE
+    from .models import DEFAULT_MODEL_TYPE, Res
+    from .log import logger
 
-    res: List[DEFAULT_MODEL_TYPE] = []
+    res: List[Res[DEFAULT_MODEL_TYPE]] = []
+    filter_type = tuple(FILTER_OPTIONS[ff] for ff in filter_)
     if cache:
-        res = list(cached_merge_takeouts(list(takeout_dir)))
+        if filter_:
+            logger.warn(
+                "As it would otherwise re-compute every time, filtering happens after loading from cache"
+            )
+        res = list(cached_merge_takeouts(list(takeout_dir), locale_name=locale))
+        if filter_:
+            res = [r for r in res if isinstance(r, filter_type)]
     else:
-        res = list(merge_events(*iter([TakeoutParser(p).parse(cache=False) for p in takeout_dir])))  # type: ignore[arg-type]
+        res = list(
+            merge_events(
+                *iter(  # type: ignore
+                    [
+                        TakeoutParser(p, locale_name=locale).parse(
+                            cache=False,
+                            filter_type=filter_type,
+                        )
+                        for p in takeout_dir
+                    ]
+                )
+            )
+        )
     _handle_action(res, action)
 
 
