@@ -3,7 +3,7 @@ Helper module to remove duplicate events when combining takeouts
 """
 
 from itertools import chain
-from typing import Set, Tuple, List, Any
+from typing import Set, Tuple, List, Any, Optional, Type
 
 
 from cachew import cachew
@@ -23,12 +23,14 @@ from .path_dispatch import TakeoutParser
 
 # Note: only used for this module, HPI caches elsewhere
 @cachew(
-    cache_path=lambda _: str(takeout_cache_path / "_merged_takeouts"),
-    depends_on=lambda pths: list(sorted([str(p) for p in pths])),
+    cache_path=str(takeout_cache_path / "_merged_takeouts"),
+    depends_on=lambda tp: str(list(sorted(str(p) for p in tp))),
     force_file=True,
     logger=logger,
 )
-def cached_merge_takeouts(takeout_paths: List[PathIsh]) -> CacheResults:
+def cached_merge_takeouts(
+    takeout_paths: List[PathIsh], locale_name: Optional[str]
+) -> CacheResults:
     """
     Cached version of merge events, merges each of these into one cachew database
 
@@ -46,7 +48,7 @@ def cached_merge_takeouts(takeout_paths: List[PathIsh]) -> CacheResults:
     """
     itrs: List[CacheResults] = []
     for pth in takeout_paths:
-        tk = TakeoutParser(pth, warn_exceptions=True)
+        tk = TakeoutParser(pth, warn_exceptions=True, locale_name=locale_name)
         # have to ignore type conversion here -- its returns BaseEvent,
         # while CacheResults is the combined Union type
         itrs.append(tk.parse(cache=True))  # type: ignore[misc,arg-type]
@@ -74,8 +76,11 @@ def merge_events(*sources: CacheResults) -> CacheResults:
     )
 
 
-def _create_key(e: BaseEvent) -> Tuple[str, Any]:
-    return (type(e).__name__, e.key)
+Key = Tuple[Type[Any], Any]
+
+
+def _create_key(e: BaseEvent) -> Key:
+    return (type(e), e.key)
 
 
 # This is so that its easier to use this logic in other
@@ -86,7 +91,7 @@ class GoogleEventSet:
     """
 
     def __init__(self) -> None:
-        self.keys: Set[Tuple[str, Any]] = set()
+        self.keys: Set[Key] = set()
 
     def __contains__(self, other: BaseEvent) -> bool:
         return _create_key(other) in self.keys
@@ -96,3 +101,14 @@ class GoogleEventSet:
 
     def add(self, other: BaseEvent) -> None:
         self.keys.add(_create_key(other))
+
+    def add_if_not_present(self, other: BaseEvent) -> bool:
+        """
+        Returns False if element already existed, True if it didn't and we added it.
+        More efficient than checking membership and adding separately, since we only compute key once.
+        """
+        key = _create_key(other)
+        if key in self.keys:
+            return False
+        self.keys.add(key)
+        return True
